# `narwhals.Expr`

::: narwhals.Expr
    handler: python
    options:
      members:
        - alias
        - cast
        - mean
        - sum
        - min
        - max
        - n_unique
        - unique
        - is_between
        - is_in
        - is_null
        - drop_nulls
        - sample
        - str
      show_root_heading: false
      show_source: false
      show_bases: false
